##  Example 1: Product Architecture
For many of our software-oriented clients, a relation exists between applications and the business product fact sheet subtype - we at SAP LeanIX internally track our SAP LeanIX as both an application that we provide to internal users and a product we offer on the market. For more complex product architectures, multiple applications can form one product to showcase all the different ways a business product comes together. Example of a product architecture:
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274cd93e7a4410149734ce0f233febfc_LowRes.png)
Deep-dive with view: applications related to business products
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274fd49a7a441014b622d679ed57de65_LowRes.png)
A good report to get relevant insights would be an application landscape report filtered to business context, showing all applications related to the different business products with lifecycle as the selected view.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27430f2f7a441014811ddc525b37d73e_LowRes.png)
Another frequently used report is the matrix report, which lets you get a quick overview of applications clustered, e.g., by business capabilities and business context. Note that you need to change the information in the report settings to get that specific view in SAP LeanIX. To learn how to use reports, see [Reports](https://help.sap.com/docs/leanix/ea/reports?locale=en-US&state=PRODUCTION&version=CLOUD).
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2748f3d97a4410149646c17568ec5e41_LowRes.png)
